@@ -2,9 +2,9 @@
 #![deny(missing_docs)]
 
 /*!
-This is [Diana's](https://diana-graphql.github.io) integration crate for Actix Web, which enables the easy deployment of a Diana system
-on that platform. For more information, see [the documentation for Diana](https://github.com/diana-graphql/diana) and
-[the book](https://diana-graphql.github.io).
+This is [Diana's](https://arctic-hen7.github.io/diana) integration crate for Actix Web, which enables the easy deployment of a Diana system
+on that platform. For more information, see [the documentation for Diana](https://github.com/arctic-hen7/diana) and
+[the book](https://arctic-hen7.github.io/diana).
 */
 
 mod auth_middleware;
